# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_adapter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/core_adapter.proto',
  package='core_adapter',
  syntax='proto3',
  serialized_options=b'\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n voltha_protos/core_adapter.proto\x12\x0c\x63ore_adapter\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1dvoltha_protos/omci_test.proto\"]\n\x13\x41\x64\x61pterRegistration\x12!\n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32\x10.adapter.Adapter\x12#\n\x06\x64Types\x18\x02 \x01(\x0b\x32\x13.device.DeviceTypes\"e\n\x11\x43hildDeviceFilter\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0e\n\x06onu_id\x18\x03 \x01(\r\x12\x16\n\x0eparent_port_no\x18\x04 \x01(\r\"W\n\nPortFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\tport_type\x18\x03 \x01(\x0e\x32\x15.device.Port.PortType\"\xa5\x01\n\x0f\x44\x65viceDiscovery\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x02 \x01(\r\x12\x19\n\x11\x63hild_device_type\x18\x03 \x01(\t\x12\x12\n\nchannel_id\x18\x04 \x01(\r\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x15\n\rserial_number\x18\x06 \x01(\t\x12\x0e\n\x06onu_id\x18\x07 \x01(\r\"\xa1\x01\n\x11\x44\x65viceStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10parent_device_id\x18\x02 \x01(\t\x12-\n\x0boper_status\x18\x03 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x30\n\x0b\x63onn_status\x18\x04 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\"\x88\x01\n\tPortState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12(\n\tport_type\x18\x02 \x01(\x0e\x32\x15.device.Port.PortType\x12\x0f\n\x07port_no\x18\x03 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\"m\n\x0fPortStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10port_type_filter\x18\x02 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\";\n\x08PacketIn\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0e\n\x06packet\x18\x03 \x01(\x0c\"c\n\tPacketOut\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65gress_port_no\x18\x02 \x01(\r\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.openflow_13.ofp_packet_out\"1\n\x0c\x44\x65viceReason\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\xa9\x01\n\tBulkFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12!\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.openflow_13.Flows\x12\'\n\x06groups\x18\x03 \x01(\x0b\x32\x17.openflow_13.FlowGroups\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"\xbc\x01\n\x10IncrementalFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\'\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x18.openflow_13.FlowChanges\x12-\n\x06groups\x18\x03 \x01(\x0b\x32\x1d.openflow_13.FlowGroupChanges\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"I\n\rPmConfigsInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\npm_configs\x18\x02 \x01(\x0b\x32\x11.device.PmConfigs\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"\\\n\x14ImageDownloadMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x15.device.ImageDownload\"R\n\x08OMCITest\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12&\n\x07request\x18\x02 \x01(\x0b\x32\x15.omci.OmciTestRequest\"e\n\x14SimulateAlarmMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12-\n\x07request\x18\x02 \x01(\x0b\x32\x1c.device.SimulateAlarmRequest\"\x90\x01\n\x12GetExtValueMessage\x12%\n\rparent_device\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x0c\x63hild_device\x18\x02 \x01(\x0b\x32\x0e.device.Device\x12-\n\nvalue_type\x18\x03 \x01(\x0e\x32\x19.extension.ValueType.Type\"X\n\x12SetExtValueMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\"\n\x05value\x18\x03 \x01(\x0b\x32\x13.extension.ValueSetBX\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapterb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,voltha__protos_dot_adapter__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_extensions__pb2.DESCRIPTOR,voltha__protos_dot_omci__test__pb2.DESCRIPTOR,])




_ADAPTERREGISTRATION = _descriptor.Descriptor(
  name='AdapterRegistration',
  full_name='core_adapter.AdapterRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adapter', full_name='core_adapter.AdapterRegistration.adapter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dTypes', full_name='core_adapter.AdapterRegistration.dTypes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=352,
)


_CHILDDEVICEFILTER = _descriptor.Descriptor(
  name='ChildDeviceFilter',
  full_name='core_adapter.ChildDeviceFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='core_adapter.ChildDeviceFilter.parent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='core_adapter.ChildDeviceFilter.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='core_adapter.ChildDeviceFilter.onu_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_port_no', full_name='core_adapter.ChildDeviceFilter.parent_port_no', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=455,
)


_PORTFILTER = _descriptor.Descriptor(
  name='PortFilter',
  full_name='core_adapter.PortFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PortFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='core_adapter.PortFilter.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type', full_name='core_adapter.PortFilter.port_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=544,
)


_DEVICEDISCOVERY = _descriptor.Descriptor(
  name='DeviceDiscovery',
  full_name='core_adapter.DeviceDiscovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='core_adapter.DeviceDiscovery.parent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_port_no', full_name='core_adapter.DeviceDiscovery.parent_port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device_type', full_name='core_adapter.DeviceDiscovery.child_device_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='core_adapter.DeviceDiscovery.channel_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='core_adapter.DeviceDiscovery.vendor_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='core_adapter.DeviceDiscovery.serial_number', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='core_adapter.DeviceDiscovery.onu_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=712,
)


_DEVICESTATEFILTER = _descriptor.Descriptor(
  name='DeviceStateFilter',
  full_name='core_adapter.DeviceStateFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.DeviceStateFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='core_adapter.DeviceStateFilter.parent_device_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='core_adapter.DeviceStateFilter.oper_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conn_status', full_name='core_adapter.DeviceStateFilter.conn_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=876,
)


_PORTSTATE = _descriptor.Descriptor(
  name='PortState',
  full_name='core_adapter.PortState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PortState.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type', full_name='core_adapter.PortState.port_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='core_adapter.PortState.port_no', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='core_adapter.PortState.oper_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=1015,
)


_PORTSTATEFILTER = _descriptor.Descriptor(
  name='PortStateFilter',
  full_name='core_adapter.PortStateFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PortStateFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type_filter', full_name='core_adapter.PortStateFilter.port_type_filter', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='core_adapter.PortStateFilter.oper_status', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1126,
)


_PACKETIN = _descriptor.Descriptor(
  name='PacketIn',
  full_name='core_adapter.PacketIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PacketIn.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='core_adapter.PacketIn.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet', full_name='core_adapter.PacketIn.packet', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1187,
)


_PACKETOUT = _descriptor.Descriptor(
  name='PacketOut',
  full_name='core_adapter.PacketOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PacketOut.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='egress_port_no', full_name='core_adapter.PacketOut.egress_port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet', full_name='core_adapter.PacketOut.packet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1189,
  serialized_end=1288,
)


_DEVICEREASON = _descriptor.Descriptor(
  name='DeviceReason',
  full_name='core_adapter.DeviceReason',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.DeviceReason.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='core_adapter.DeviceReason.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1339,
)


_BULKFLOWS = _descriptor.Descriptor(
  name='BulkFlows',
  full_name='core_adapter.BulkFlows',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.BulkFlows.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='core_adapter.BulkFlows.flows', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='core_adapter.BulkFlows.groups', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_metadata', full_name='core_adapter.BulkFlows.flow_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1511,
)


_INCREMENTALFLOWS = _descriptor.Descriptor(
  name='IncrementalFlows',
  full_name='core_adapter.IncrementalFlows',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.IncrementalFlows.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='core_adapter.IncrementalFlows.flows', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='core_adapter.IncrementalFlows.groups', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_metadata', full_name='core_adapter.IncrementalFlows.flow_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1702,
)


_PMCONFIGSINFO = _descriptor.Descriptor(
  name='PmConfigsInfo',
  full_name='core_adapter.PmConfigsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='core_adapter.PmConfigsInfo.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pm_configs', full_name='core_adapter.PmConfigsInfo.pm_configs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1704,
  serialized_end=1777,
)


_SWITCHCAPABILITY = _descriptor.Descriptor(
  name='SwitchCapability',
  full_name='core_adapter.SwitchCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='core_adapter.SwitchCapability.desc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_features', full_name='core_adapter.SwitchCapability.switch_features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1779,
  serialized_end=1893,
)


_IMAGEDOWNLOADMESSAGE = _descriptor.Descriptor(
  name='ImageDownloadMessage',
  full_name='core_adapter.ImageDownloadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.ImageDownloadMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='core_adapter.ImageDownloadMessage.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1895,
  serialized_end=1987,
)


_OMCITEST = _descriptor.Descriptor(
  name='OMCITest',
  full_name='core_adapter.OMCITest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.OMCITest.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='core_adapter.OMCITest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2071,
)


_SIMULATEALARMMESSAGE = _descriptor.Descriptor(
  name='SimulateAlarmMessage',
  full_name='core_adapter.SimulateAlarmMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.SimulateAlarmMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='core_adapter.SimulateAlarmMessage.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2174,
)


_GETEXTVALUEMESSAGE = _descriptor.Descriptor(
  name='GetExtValueMessage',
  full_name='core_adapter.GetExtValueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_device', full_name='core_adapter.GetExtValueMessage.parent_device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device', full_name='core_adapter.GetExtValueMessage.child_device', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='core_adapter.GetExtValueMessage.value_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2177,
  serialized_end=2321,
)


_SETEXTVALUEMESSAGE = _descriptor.Descriptor(
  name='SetExtValueMessage',
  full_name='core_adapter.SetExtValueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='core_adapter.SetExtValueMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='core_adapter.SetExtValueMessage.value', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2411,
)

_ADAPTERREGISTRATION.fields_by_name['adapter'].message_type = voltha__protos_dot_adapter__pb2._ADAPTER
_ADAPTERREGISTRATION.fields_by_name['dTypes'].message_type = voltha__protos_dot_device__pb2._DEVICETYPES
_PORTFILTER.fields_by_name['port_type'].enum_type = voltha__protos_dot_device__pb2._PORT_PORTTYPE
_DEVICESTATEFILTER.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_DEVICESTATEFILTER.fields_by_name['conn_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_PORTSTATE.fields_by_name['port_type'].enum_type = voltha__protos_dot_device__pb2._PORT_PORTTYPE
_PORTSTATE.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_PORTSTATEFILTER.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_PACKETOUT.fields_by_name['packet'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_PACKET_OUT
_BULKFLOWS.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_BULKFLOWS.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWS
_BULKFLOWS.fields_by_name['groups'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWGROUPS
_BULKFLOWS.fields_by_name['flow_metadata'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWMETADATA
_INCREMENTALFLOWS.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_INCREMENTALFLOWS.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWCHANGES
_INCREMENTALFLOWS.fields_by_name['groups'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWGROUPCHANGES
_INCREMENTALFLOWS.fields_by_name['flow_metadata'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWMETADATA
_PMCONFIGSINFO.fields_by_name['pm_configs'].message_type = voltha__protos_dot_device__pb2._PMCONFIGS
_SWITCHCAPABILITY.fields_by_name['desc'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_DESC
_SWITCHCAPABILITY.fields_by_name['switch_features'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_SWITCH_FEATURES
_IMAGEDOWNLOADMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_IMAGEDOWNLOADMESSAGE.fields_by_name['image'].message_type = voltha__protos_dot_device__pb2._IMAGEDOWNLOAD
_OMCITEST.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_OMCITEST.fields_by_name['request'].message_type = voltha__protos_dot_omci__test__pb2._OMCITESTREQUEST
_SIMULATEALARMMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_SIMULATEALARMMESSAGE.fields_by_name['request'].message_type = voltha__protos_dot_device__pb2._SIMULATEALARMREQUEST
_GETEXTVALUEMESSAGE.fields_by_name['parent_device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_GETEXTVALUEMESSAGE.fields_by_name['child_device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_GETEXTVALUEMESSAGE.fields_by_name['value_type'].enum_type = voltha__protos_dot_extensions__pb2._VALUETYPE_TYPE
_SETEXTVALUEMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_SETEXTVALUEMESSAGE.fields_by_name['value'].message_type = voltha__protos_dot_extensions__pb2._VALUESET
DESCRIPTOR.message_types_by_name['AdapterRegistration'] = _ADAPTERREGISTRATION
DESCRIPTOR.message_types_by_name['ChildDeviceFilter'] = _CHILDDEVICEFILTER
DESCRIPTOR.message_types_by_name['PortFilter'] = _PORTFILTER
DESCRIPTOR.message_types_by_name['DeviceDiscovery'] = _DEVICEDISCOVERY
DESCRIPTOR.message_types_by_name['DeviceStateFilter'] = _DEVICESTATEFILTER
DESCRIPTOR.message_types_by_name['PortState'] = _PORTSTATE
DESCRIPTOR.message_types_by_name['PortStateFilter'] = _PORTSTATEFILTER
DESCRIPTOR.message_types_by_name['PacketIn'] = _PACKETIN
DESCRIPTOR.message_types_by_name['PacketOut'] = _PACKETOUT
DESCRIPTOR.message_types_by_name['DeviceReason'] = _DEVICEREASON
DESCRIPTOR.message_types_by_name['BulkFlows'] = _BULKFLOWS
DESCRIPTOR.message_types_by_name['IncrementalFlows'] = _INCREMENTALFLOWS
DESCRIPTOR.message_types_by_name['PmConfigsInfo'] = _PMCONFIGSINFO
DESCRIPTOR.message_types_by_name['SwitchCapability'] = _SWITCHCAPABILITY
DESCRIPTOR.message_types_by_name['ImageDownloadMessage'] = _IMAGEDOWNLOADMESSAGE
DESCRIPTOR.message_types_by_name['OMCITest'] = _OMCITEST
DESCRIPTOR.message_types_by_name['SimulateAlarmMessage'] = _SIMULATEALARMMESSAGE
DESCRIPTOR.message_types_by_name['GetExtValueMessage'] = _GETEXTVALUEMESSAGE
DESCRIPTOR.message_types_by_name['SetExtValueMessage'] = _SETEXTVALUEMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdapterRegistration = _reflection.GeneratedProtocolMessageType('AdapterRegistration', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERREGISTRATION,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.AdapterRegistration)
  })
_sym_db.RegisterMessage(AdapterRegistration)

ChildDeviceFilter = _reflection.GeneratedProtocolMessageType('ChildDeviceFilter', (_message.Message,), {
  'DESCRIPTOR' : _CHILDDEVICEFILTER,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.ChildDeviceFilter)
  })
_sym_db.RegisterMessage(ChildDeviceFilter)

PortFilter = _reflection.GeneratedProtocolMessageType('PortFilter', (_message.Message,), {
  'DESCRIPTOR' : _PORTFILTER,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PortFilter)
  })
_sym_db.RegisterMessage(PortFilter)

DeviceDiscovery = _reflection.GeneratedProtocolMessageType('DeviceDiscovery', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDISCOVERY,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.DeviceDiscovery)
  })
_sym_db.RegisterMessage(DeviceDiscovery)

DeviceStateFilter = _reflection.GeneratedProtocolMessageType('DeviceStateFilter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESTATEFILTER,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.DeviceStateFilter)
  })
_sym_db.RegisterMessage(DeviceStateFilter)

PortState = _reflection.GeneratedProtocolMessageType('PortState', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATE,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PortState)
  })
_sym_db.RegisterMessage(PortState)

PortStateFilter = _reflection.GeneratedProtocolMessageType('PortStateFilter', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATEFILTER,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PortStateFilter)
  })
_sym_db.RegisterMessage(PortStateFilter)

PacketIn = _reflection.GeneratedProtocolMessageType('PacketIn', (_message.Message,), {
  'DESCRIPTOR' : _PACKETIN,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PacketIn)
  })
_sym_db.RegisterMessage(PacketIn)

PacketOut = _reflection.GeneratedProtocolMessageType('PacketOut', (_message.Message,), {
  'DESCRIPTOR' : _PACKETOUT,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PacketOut)
  })
_sym_db.RegisterMessage(PacketOut)

DeviceReason = _reflection.GeneratedProtocolMessageType('DeviceReason', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEREASON,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.DeviceReason)
  })
_sym_db.RegisterMessage(DeviceReason)

BulkFlows = _reflection.GeneratedProtocolMessageType('BulkFlows', (_message.Message,), {
  'DESCRIPTOR' : _BULKFLOWS,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.BulkFlows)
  })
_sym_db.RegisterMessage(BulkFlows)

IncrementalFlows = _reflection.GeneratedProtocolMessageType('IncrementalFlows', (_message.Message,), {
  'DESCRIPTOR' : _INCREMENTALFLOWS,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.IncrementalFlows)
  })
_sym_db.RegisterMessage(IncrementalFlows)

PmConfigsInfo = _reflection.GeneratedProtocolMessageType('PmConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PMCONFIGSINFO,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.PmConfigsInfo)
  })
_sym_db.RegisterMessage(PmConfigsInfo)

SwitchCapability = _reflection.GeneratedProtocolMessageType('SwitchCapability', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHCAPABILITY,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.SwitchCapability)
  })
_sym_db.RegisterMessage(SwitchCapability)

ImageDownloadMessage = _reflection.GeneratedProtocolMessageType('ImageDownloadMessage', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEDOWNLOADMESSAGE,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.ImageDownloadMessage)
  })
_sym_db.RegisterMessage(ImageDownloadMessage)

OMCITest = _reflection.GeneratedProtocolMessageType('OMCITest', (_message.Message,), {
  'DESCRIPTOR' : _OMCITEST,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.OMCITest)
  })
_sym_db.RegisterMessage(OMCITest)

SimulateAlarmMessage = _reflection.GeneratedProtocolMessageType('SimulateAlarmMessage', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEALARMMESSAGE,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.SimulateAlarmMessage)
  })
_sym_db.RegisterMessage(SimulateAlarmMessage)

GetExtValueMessage = _reflection.GeneratedProtocolMessageType('GetExtValueMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTVALUEMESSAGE,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.GetExtValueMessage)
  })
_sym_db.RegisterMessage(GetExtValueMessage)

SetExtValueMessage = _reflection.GeneratedProtocolMessageType('SetExtValueMessage', (_message.Message,), {
  'DESCRIPTOR' : _SETEXTVALUEMESSAGE,
  '__module__' : 'voltha_protos.core_adapter_pb2'
  # @@protoc_insertion_point(class_scope:core_adapter.SetExtValueMessage)
  })
_sym_db.RegisterMessage(SetExtValueMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
